@@ -14,10 +14,9 @@
 # classes.py
 # Copyright (C) 2014 Fracpete (fracpete at gmail dot com)
 
-import arrays
+import types
 import javabridge
 from javabridge.jutil import JavaException
-import weka.core.jvm as jvm
 
 
 class JavaObject(object):
@@ -196,7 +195,7 @@ class OptionHandler(JavaObject):
         :type options: list
         """
         if self.is_optionhandler:
-            javabridge.call(self.jobject, "setOptions", "([Ljava/lang/String;)V", arrays.string_list_to_array(options))
+            javabridge.call(self.jobject, "setOptions", "([Ljava/lang/String;)V", types.string_list_to_array(options))
                                                        
     def get_options(self):
         """
@@ -205,7 +204,7 @@ class OptionHandler(JavaObject):
         :rtype: list
         """
         if self.is_optionhandler:
-            return arrays.string_array_to_list(javabridge.call(self.jobject, "getOptions", "()[Ljava/lang/String;"))
+            return types.string_array_to_list(javabridge.call(self.jobject, "getOptions", "()[Ljava/lang/String;"))
         else:
             return []
 
@@ -320,7 +319,7 @@ class Range(JavaObject):
         :return: the list of 0-based integer indices
         :rtype: list
         """
-        return jvm.ENV.get_int_array_elements(javabridge.call(self.jobject, "getSelection", "()[I"))
+        return javabridge.get_env().get_int_array_elements(javabridge.call(self.jobject, "getSelection", "()[I"))
 
     def get_ranges(self):
         """
