@@ -252,7 +252,7 @@ def install_package(pkge, version="Latest"):
     """
     establish_cache()
     if pkge.startswith("http://") or pkge.startswith("https://"):
-        url = javabridge.make_instance("java/net/URL", "(Ljava/lang/String;)V", jvm.ENV.new_string_utf(pkge))
+        url = javabridge.make_instance("java/net/URL", "(Ljava/lang/String;)V", javabridge.get_env().new_string_utf(pkge))
         return not javabridge.static_call(
             "weka/core/WekaPackageManager", "installPackageFromURL",
             "(Ljava/net/URL;[Ljava/io/PrintStream;)Ljava/lang/String;", url, []) is None
@@ -279,6 +279,21 @@ def uninstall_package(name):
         "weka/core/WekaPackageManager", "uninstallPackage",
         "(Ljava/lang/String;Z[Ljava/io/PrintStream;)V", name, True, [])
 
+
+def is_installed(name):
+    """
+    Checks whether a package with the name is already installed.
+    :param name: the name of the package
+    :type name: str
+    :return: whether the package is installed
+    :rtype: bool
+    """
+    pkgs = get_installed_packages()
+    for pkge in pkgs:
+        if pkge.get_name() == name:
+            return True
+    return False
+
 if __name__ == "__main__":
     jvm.start()
     try:
