@@ -18,19 +18,21 @@ import javabridge
 import matplotlib.pyplot as plt
 from weka.core.classes import JavaObject
 from weka.core.dataset import Instances
-from weka.classifiers import NumericPrediction
+from weka.classifiers import NumericPrediction, NominalPrediction
 
 
-def plot_classifier_errors(predictions, absolute=True, max_relative_size=20, outfile=None, wait=True):
+def plot_classifier_errors(predictions, absolute=True, max_relative_size=20, absolute_size=50, outfile=None, wait=True):
     """
     Plots the classifers for the given list of predictions.
-    NB: The plot window blocks execution till closed.
+    TODO: click events http://matplotlib.org/examples/event_handling/data_browser.html
     :param predictions: the predictions to plot
     :type predictions: list
     :param absolute: whether to use absolute errors as size or relative ones
     :type absolute: bool
     :param max_relative_size: the maximum size in point in case of relative mode
     :type max_relative_size: int
+    :param absolute_size: the size in point in case of absolute mode
+    :type absolute_size: int
     :param outfile: the output file, ignored if None
     :type outfile: str
     :param wait: whether to wait for the user to close the plot
@@ -39,6 +41,7 @@ def plot_classifier_errors(predictions, absolute=True, max_relative_size=20, out
     actual    = []
     predicted = []
     error     = None
+    cls       = None
     for pred in predictions:
         actual.append(pred.actual())
         predicted.append(pred.predicted())
@@ -46,17 +49,26 @@ def plot_classifier_errors(predictions, absolute=True, max_relative_size=20, out
             if error is None:
                 error = []
             error.append(abs(pred.error()))
+        elif isinstance(pred, NominalPrediction):
+            if cls is None:
+                cls = []
+            if pred.actual() != pred.predicted():
+                cls.append(1)
+            else:
+                cls.append(0)
     fig, ax = plt.subplots()
-    if error is None:
-        ax.scatter(actual, predicted)
-    else:
+    if error is None and cls is None:
+        ax.scatter(actual, predicted, s=absolute_size, alpha=0.5)
+    elif not cls is None:
+        ax.scatter(actual, predicted, c=cls, s=absolute_size, alpha=0.5)
+    elif not error is None:
         if not absolute:
             min_err = min(error)
             max_err = max(error)
             factor  = (max_err  - min_err) / max_relative_size
             for i in xrange(len(error)):
                 error[i] = error[i] / factor * max_relative_size
-        ax.scatter(actual, predicted, s=error)
+        ax.scatter(actual, predicted, s=error, alpha=0.5)
     ax.set_xlabel("actual")
     ax.set_ylabel("predicted")
     ax.set_title("Classifier errors")
@@ -72,6 +84,7 @@ def plot_classifier_errors(predictions, absolute=True, max_relative_size=20, out
 def plot_roc(evaluation, class_index=0, outfile=None, wait=True):
     """
     Plots the ROC (receiver operator characteristics) curve for the given predictions.
+    TODO: click events http://matplotlib.org/examples/event_handling/data_browser.html
     :param evaluation: the evaluation to obtain the predictions from
     :type evaluation: Evaluation
     :param class_index: the 0-based index of the class-label to create the plot for
