@@ -24,6 +24,7 @@ from weka.filters import Filter
 from weka.core.classes import Random
 import weka.plot.classifiers as plot_cls
 import weka.plot.graph as plot_graph
+import weka.core.types as types
 
 
 def main():
@@ -40,7 +41,11 @@ def main():
 
     # build a classifier and output model
     helper.print_title("Training J48 classifier on iris")
-    classifier = Classifier(classname="weka.classifiers.trees.J48", options=["-C", "0.3"])
+    classifier = Classifier(classname="weka.classifiers.trees.J48")
+    # Instead of using 'options=["-C", "0.3"]' in the constructor, we can also set the "confidenceFactor"
+    # property of the J48 classifier itself. However, being of type float rather than double, we need
+    # to convert it to the correct type first using the double_to_float function:
+    classifier.set_property("confidenceFactor", types.double_to_float(0.3))
     classifier.build_classifier(iris_data)
     print(classifier)
     print(classifier.graph())
@@ -104,13 +109,13 @@ def main():
     print(meta.to_commandline())
 
     # cross-validate nominal classifier
-    helper.print_title("Cross-validating SMO on anneal")
-    anneal_file = helper.get_data_dir() + os.sep + "anneal.arff"
+    helper.print_title("Cross-validating NaiveBayes on diabetes")
+    anneal_file = helper.get_data_dir() + os.sep + "diabetes.arff"
     helper.print_info("Loading dataset: " + anneal_file)
     loader = Loader("weka.core.converters.ArffLoader")
     anneal_data = loader.load_file(anneal_file)
     anneal_data.set_class_index(anneal_data.num_attributes() - 1)
-    classifier = Classifier(classname="weka.classifiers.functions.SMO", options=["-M"])
+    classifier = Classifier(classname="weka.classifiers.bayes.NaiveBayes")
     evaluation = Evaluation(anneal_data)
     evaluation.crossvalidate_model(classifier, anneal_data, 10, Random(42))
     print(evaluation.to_summary())
